==> connectagram_1.2.10.orig.tar.gz: connectagram-1.2.10/translations/connectagram_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Lánc</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Szünet</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definíciók</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Meghatározás letöltése...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Még nem kitalált szó</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definíció a Wiktionary ingyenes szótárból</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Nem található meghatározás</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Nem sikerült kapcsolódni a Wiktionary szótárhoz</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Kerítés</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Program nyelve:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Rendszer nyelve&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>A nyelvi változások érvénybelépéséhez újra kell indítani a programot.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Új játék</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Kevés</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Sok</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Nagyon sok</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Nyelv:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Szavak hossza:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Szavak száma:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n betű</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Gyűrűk</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Eredmények</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Eredmény</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Szavak</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Hossz</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Lépcső</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Csavaros</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Hullám</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sikerült</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definíciók</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Tipp</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Játék</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Ú&amp;j</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>K&amp;iválaszt...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Részletek</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Szünet</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Tipp</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>&amp;Definíciók</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Eredmények</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Program nye&amp;lve...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt névjegye</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Játék kiválasztása</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Játék száma:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Nem sikerült</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nem sikerült betölteni a kért játékot.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Szókirakó játék</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definíciók a &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt; ingyenes szótárból</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Minta:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Folytat</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Lánc</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Szünet</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Kerítés</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Program nyelve:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Rendszer nyelve&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>A nyelvi változások érvénybelépéséhez újra kell indítani a programot.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Új játék</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Kevés</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Sok</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Nagyon sok</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Nyelv:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Szavak hossza:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Szavak száma:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n betű</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Gyűrűk</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Eredmény</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Szavak</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Hossz</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Lépcső</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Csavaros</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Hullám</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sikerült</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definíciók</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Tipp</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Játék</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Ú&amp;j</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>K&amp;iválaszt...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Részletek</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Szünet</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Tipp</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>&amp;Definíciók</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Program nye&amp;lve...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt névjegye</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Játék kiválasztása</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Játék száma:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Nem sikerült</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nem sikerült betölteni a kért játékot.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Szókirakó játék</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Definíciók a &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt; ingyenes szótárból</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Minta:</translation>
    </message>
</context>
</TS>
